\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{pmfmo_phd}[2020/02/20 23:59 Doktorska disertacija, PMF-MO, Zagreb, Hrvatska]
%
%%%%%%%%%% DOCUMENTCLASS %%%%%%%%%%
\LoadClass[a4paper, 12pt, oneside, openany]{book}
%
%%%%%%%%%% HRVATSKI JEZIK i KODIRANJE %%%%%%%%%%
\RequirePackage{ifpdf}
\RequirePackage{cmap}
\RequirePackage[T2A,T1]{fontenc}
\RequirePackage[utf8]{inputenc}
\RequirePackage[croatian]{babel}
\RequirePackage{mathptmx}
%
%%%%%%%%%% AMS I MATEMATIKA %%%%%%%%%%
\RequirePackage{amssymb, amsmath, amsthm, amsfonts}
\RequirePackage{mathtools}
\RequirePackage{yhmath}
%
%%%%%%%%%% OSTALI PAKETI %%%%%%%%%%
\RequirePackage{multirow}
\RequirePackage{graphicx}
\RequirePackage{enumerate}
\RequirePackage{enumitem}
\RequirePackage{babelbib}
\RequirePackage{color}
\RequirePackage{xcolor}
\RequirePackage{etoolbox}
\RequirePackage{datatool}
\RequirePackage{xparse}
\RequirePackage{accsupp}
\RequirePackage{cite}
%
\definecolor{dark-blue}{rgb}{0.15,0.15,0.4}
\definecolor{medium-blue}{rgb}{0,0,0.5}
\definecolor{dark-red}{rgb}{0.4,0.15,0.15}
\RequirePackage[
	pagebackref=true,
	unicode=true,
	breaklinks=true,
	pdfsubject={doktorska disertacija},
	pdfstartpage={1},
	pdfstartview=FitH,
	linktocpage=false,
	bookmarksopen=true,
	bookmarksopenlevel=1,
	bookmarksnumbered=false,
	colorlinks=true,
	linkcolor={dark-blue},
	citecolor={medium-blue},
	urlcolor={dark-red},
	filecolor=yellow,
	]{hyperref}
\apptocmd{\sloppy}{\hbadness 10000\relax}{}{}
\renewcommand*{\backrefalt}[4]{
	\ifcase #1 %
	\else $\uparrow$ {\footnotesize #2.}%
	\fi
	}
\renewcommand*{\backreftwosep}{, }
\renewcommand*{\backreflastsep}{, }
%%%%%%%%%% MARGINE I PRORED %%%%%%%%%%
\RequirePackage[margin=25mm,centering]{geometry}
\linespread{1.5}
%
%%%%%%%%%% ISPIS BROJEVA STRANICA DOLJE DESNO %%%%%%%%%%
\RequirePackage{fancyhdr}
\pagestyle{fancy}
\setlength{\headheight}{15.14pt}
\renewcommand{\sectionmark}[1]{\markright{#1}}
\renewcommand{\chaptermark}[1]{\markboth{#1}{}}
\fancyhf{}
\renewcommand{\headrulewidth}{0.4pt}
\renewcommand{\footrulewidth}{0pt}
\lhead{\bfseries\nouppercase\leftmark}
\rhead{\itshape\nouppercase\rightmark}
\rfoot{\thepage}
\fancypagestyle{plain}{
	\fancyhf{}
	\renewcommand{\headrulewidth}{0pt}
	\renewcommand{\footrulewidth}{0pt}
	\rfoot{\thepage}
}
%
%%%%%%%%%% IZGLED NASLOVA POGLAVLJA, SEKCIJA, PODSEKCIJA %%%%%%%%%%
\RequirePackage{titlesec}
\titleformat{\chapter}[hang]{\scshape\Huge\centering}{\thechapter.}{15pt}{}[]
\titleformat{\section}[hang]{\scshape\LARGE\centering}{\thesection.}{10pt}{}[]
\newcommand\sectionbreak{\ifthenelse{\value{section}>1}{\clearpage}{}}
\titleformat{\subsection}[hang]{\large}{\thesubsection.}{5pt}{}[]
%
%%%%%%%%%% KONFIGURACIJSKE NAREDBE %%%%%%%%%%
\newcommand*{\PMFMO}{PRIRODOSLOVNO--MATEMATI\v CKI FAKULTET\\MATEMATI\v CKI ODSJEK}
\newcommand*{\PMFMOeng}{FACULTY OF SCIENCE\\DEPARTMENT OF MATHEMATICS}
\newcommand*{\DOKTORSKI}{DOKTORSKI RAD}
\newcommand*{\DOKTORSKIeng}{DOCTORAL DISSERTATION}
\newcommand*\AUTOR[1]{\renewcommand\@AUTOR{#1}}
\newcommand*\@AUTOR{Autor}
\newcommand*\NASLOV[1]{\renewcommand\@NASLOV{#1}}
\newcommand*\@NASLOV{Naslov}
\newcommand*\NASLOVeng[1]{\renewcommand\@NASLOVeng{#1}}
\newcommand*\@NASLOVeng{Nasloveng}
\newcommand*\GODINA[1]{\renewcommand\@GODINA{#1}}
\newcommand*\@GODINA{0000}
\newcommand*\MJESTODATUM{Zagreb, \@GODINA.}
%%%%%%%%%% MENTOR - JEDAN ILI VIŠE NJIH (odvojenih zarezom!)
\newcommand*\kolikomentora{0}
\newcommand*\MENTOR[1]{
	\renewcommand\@MENTOR{#1}
	\DTLnumitemsinlist{\@MENTOR}{\kolikomentora}
}
\newcommand*\@MENTOR{Mentor}
\newcommand*\MENTORISPIS{
	\ifthenelse{\kolikomentora > 1}%
		{Mentori}{Mentor}:\\\@MENTOR
	}
\newcommand*\SUPERVISORISPIS{
	\ifthenelse{\kolikomentora > 1}%
		{Supervisors}{Supervisor}:\\\@MENTOR
	}
%ZAHVALA
\newif\ifzahvala
\zahvalafalse
%EMPTYSTYLE NASLOVNICE & GRB SVUČILIŠTA
\newcommand*\GRB[1]{
	\thispagestyle{empty}
	\begin{figure}[h!]
		\centering
		\includegraphics[height=3.9cm]{osnovno/#1}
	\end{figure}
	}
%%%%%%%%%% NAREDBA ZA VELICINE FONTA NA NASLOVNICAMA
\newcommand*\@MOJFONT[2]{\fontsize{#1pt}{#2pt}\selectfont}
%
%%%%%%%%%% KONSTRUKCIJA NASLOVNICA %%%%%%%%%%
\renewcommand\titlepage{
	\pagenumbering{gobble}
	\newgeometry{margin=30mm,centering}
	{\fontfamily{phv}\selectfont
	\begin{center}
	%%%%%%%%%%  KORICE  %%%%%%%%%%
	\GRB{logo_ver5hr.pdf}
	{\@MOJFONT{16}{19}
		\PMFMO
		\vskip 50pt
		\@AUTOR}
	\vskip 110pt
	\@MOJFONT{22}{26}\textbf{\@NASLOV}
	\vskip 50pt
	\@MOJFONT{16}{19}\DOKTORSKI
	\vfill
	\@MOJFONT{14}{17}\MJESTODATUM
	\newpage
	%%%%%%%%%%  PRVA PISANA STRANICA  %%%%%%%%%%
	\GRB{logo_ver5hr.pdf}
	{\@MOJFONT{16}{19}
		\PMFMO
		\vskip 40pt
		\@AUTOR}
	\vskip 50pt
	\@MOJFONT{22}{26}\textbf{\@NASLOV}
	\vskip 50pt
	{\@MOJFONT{16pt}{19}
		\DOKTORSKI
		\vskip 50pt
		\MENTORISPIS}
	\vfill
	\@MOJFONT{14}{17}\MJESTODATUM
	\newpage
	%%%%%%%%%%  DRUGA PISANA STRANICA  %%%%%%%%%%
	\GRB{logo_ver5en.pdf}
	{\@MOJFONT{16}{19}
		\PMFMOeng
		\vskip 40pt
		\@AUTOR}
	\vskip 50pt
	\@MOJFONT{22}{26}\textbf{\@NASLOVeng}
	\vskip 50pt
	{\@MOJFONT{16}{19}
		\DOKTORSKIeng
		\vskip 50pt
		\SUPERVISORISPIS}
	\vfill
	\@MOJFONT{14}{17}\MJESTODATUM
	\newpage
	\end{center}}
	\restoregeometry
	\pagenumbering{roman}
}
%
%%%%%%%%%% KONSTRUKCIJA POCETKA: naslovnice, zahvala?, sazetak, summary, sadrzaj %%%%%%%%%%
\setcounter{tocdepth}{2}
\renewcommand\frontmatter{
	\titlepage
	\ifzahvala \input{osnovno/zahvala} \fi
	\input{osnovno/sazetak}
	\input{osnovno/summary}
	\tableofcontents
}
%
%%%%%%%%%% IZGLED TEOREMA, LEMA, DEFINICIJA, ITD. %%%%%%%%%%
\newtheoremstyle{stil}{}{}{}{0pt}{\bfseries}{.}{10pt}{}
\theoremstyle{stil}
\newtheorem{teo}{Teorem}[section]
\newtheorem{pro}[teo]{Propozicija}
\newtheorem{kor}[teo]{Korolar}
\newtheorem{lem}[teo]{Lema}
\newtheorem{dfn}[teo]{Definicija}
\newtheorem{nap}[teo]{Napomena}
\newtheorem*{teo*}{Teorem}
\newtheorem*{pro*}{Propozicija}
\newtheorem*{kor*}{Korolar}
\newtheorem*{lem*}{Lema}
\newtheorem*{dfn*}{Definicija}
\newtheorem*{nap*}{Napomena}
\renewcommand{\qedsymbol}{\ensuremath{\blacksquare}}
%
%%%%%%%%%% BIBLIOGRAFIJA %%%%%%%%%%
\newcommand*{\bibliografija}[1]{
	\nocite{*}
	\bibliographystyle{babplain}
	\cleardoublepage
	\phantomsection
	\addcontentsline{toc}{chapter}{\bibname}
	\bibliography{#1}
}
%